@@ -24,6 +24,10 @@
 #include <glib.h>
 #include "gconf-error.h"
 
+#ifdef __cplusplus
+extern "C" {
+#endif /* __cplusplus */
+
 /* 
  * A GConfValue is used to pass configuration values around
  */
@@ -55,22 +59,6 @@ typedef struct _GConfValue GConfValue;
 
 struct _GConfValue {
   GConfValueType type;
-  /* this is all PRIVATE dangit */      
-  union {
-    gchar* string_data;
-    gint int_data;
-    gboolean bool_data;
-    gdouble float_data;
-    GConfSchema* schema_data;
-    struct {
-      GConfValueType type;
-      GSList* list;
-    } list_data;
-    struct {
-      GConfValue* car;
-      GConfValue* cdr;
-    } pair_data;
-  } d;
 };
 
 const char*    gconf_value_get_string    (const GConfValue *value);
@@ -164,17 +152,6 @@ typedef struct _GConfEntry GConfEntry;
 struct _GConfEntry {
   char *key;
   GConfValue *value;
-  char *schema_name;
-  int pad1;
-  gpointer pad2;
-  gpointer pad3;
-  GTime pad4;
-  int refcount;
-  guint is_default : 1;
-  guint is_writable : 1;
-  guint pad5 : 1;
-  guint pad6 : 1;
-  guint pad7 : 1;
 };
 
 const char* gconf_entry_get_key         (const GConfEntry *entry);
@@ -187,7 +164,13 @@ GConfEntry* gconf_entry_new              (const gchar *key,
                                           const GConfValue  *val);
 GConfEntry* gconf_entry_new_nocopy       (gchar       *key,
                                           GConfValue  *val);
+
+GConfEntry* gconf_entry_copy             (const GConfEntry *src);
+#ifndef GCONF_DISABLE_DEPRECATED
 void        gconf_entry_free             (GConfEntry  *entry);
+#endif
+void        gconf_entry_ref   (GConfEntry *entry);
+void        gconf_entry_unref (GConfEntry *entry);
 
 /* Transfer ownership of value to the caller. */
 GConfValue* gconf_entry_steal_value      (GConfEntry  *entry);
@@ -202,6 +185,10 @@ void        gconf_entry_set_is_default   (GConfEntry  *entry,
 void        gconf_entry_set_is_writable  (GConfEntry  *entry,
                                           gboolean     is_writable);
 
+#ifdef __cplusplus
+}
+#endif /* __cplusplus */
+
 #endif
 
 
